@@ -1,3 +1,9 @@
+"""
+:organization: Logilab
+:copyright: 2013 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+"""
+
 from logilab.common.decorators import monkeypatch
 
 from cubicweb import view as cwview
@@ -33,7 +39,7 @@ def _field_as_table(self, label, value, show_label=True,  tr=True, w=None):
 
 @monkeypatch(cwview.View)
 def _field_as_div(self, label, value, show_label=True, w=None):
-    self.w(u'<div class="row-fluid">')
+    self.w(u'<div class="row">')
     if show_label and label:
         self.w(u'<h6 class="col-md-4">%s</h6>'% display_name(self._cw, label))
         value_cols = 8
