@@ -69,7 +69,7 @@ class ModalFormRenderer(formrenderers.FormRenderer):
                     'class': u'modal fade in' if showmessage else u'modal'}]
         html.append(super(ModalFormRenderer, self).open_form(form, values, **attrs))
         html.append((u'<div class="modal-header">\n'
-                  u'<button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>\n'
+                  u'<button type="button" class="close" data-dismiss="modal" aria-hidden="true">&#215;</button>\n'
                   u'<div class="modal-title">%s</div>\n'
                   u'</div>\n' % values.get('title', u'')))
         return u'\n'.join(html)
