@@ -61,7 +61,7 @@ def bwcompatible_render_item(w, item):
 @monkeypatch(htmlwidgets.PopupBoxMenu)
 def _render(self):
     self.w(u'<div id="%s" class="btn-group">' % self.ident)
-    self.w(u'<a class="btn btn-default btn-sm dropdown-toggle" data-toggle="dropdown" href="#">'
+    self.w(u'<a class="dropdown-toggle" data-toggle="dropdown" href="#">'
            u' %s '
            u'<span class="caret"></span>'
            u'</a>' % self.label)
